@@ -1,5 +1,4 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 # Copyright (C) 2016, the Pyzo development team
 #
 # Pyzo is distributed under the terms of the (new) BSD License.
@@ -28,7 +27,7 @@ import subprocess
 # faulthandler helps debugging hard crashes, it is included in py3.3
 try:
     if sys.executable.lower().endswith("pythonw.exe"):
-        raise ImportError("Dont use faulthandler in pythonw.exe")
+        raise ImportError("Don't use faulthandler in pythonw.exe")
     if sys.platform == "win32":
         raise ImportError("Prevent crash with QFileIconProvider")
         # see https://github.com/pyzo/pyzo/issues/875 for details
